package db

import (
	"code.fnuoos.com/go_rely_warehouse/zyos_go_coupon.git/db/model"
	"code.fnuoos.com/go_rely_warehouse/zyos_go_coupon.git/utils"
	"fmt"
	"xorm.io/xorm"
)

//统计金额
func GetCouponUserOrdBySum(Db *xorm.Engine, condition *model.CommCouponUserOrd, cols string) (float64, error) {
	total, err := Db.Sum(condition, cols)
	if err != nil {
		return 0, err
	}
	return total, err
}

//统计金额
func GetCouponUserOrdBySumWithOrdType(Db *xorm.Engine, uid int, cols string, ordType ...int) (float64, error) {
	session := Db.Where("1=1")
	if uid > 0 {
		session = session.And("uid=?", uid)
	}
	if len(ordType) > 0 {
		session = session.In("ord_type", ordType)
	}
	total, err := session.Sum(&model.CommCouponUserOrd{}, cols)
	if err != nil {
		return 0, err
	}
	return total, err
}

//统计数量
func GetCouponUserOrdByCount(Db *xorm.Engine, condition *model.CommCouponUserOrd, createAt string) (total int64, err error) {
	if createAt != "" {
		total, err = Db.Where("create_at >= ? ", createAt).Count(condition)
	} else {
		total, err = Db.Count(condition)
	}
	fmt.Println(createAt)
	fmt.Println(total)
	if err != nil {
		return 0, err
	}
	return total, err
}
func CouponUserOrdByInsert(session *xorm.Session, m *model.CommCouponUserOrd) bool {
	_, err := session.Insert(m)
	if err != nil {
		return false
	}
	return true
}

func CouponUserOrdByGidAscBatch(session *xorm.Session, uid string, gid string, refundState int, goodsType string) (*model.CommCouponUserOrd, error) {
	var m model.CommCouponUserOrd
	session = session.Where("uid=? AND  type= ? and gid=? and refund_state=?", uid, 1, gid, refundState)
	if goodsType != "" {
		session = session.And("goods_type=?", goodsType)
	}
	has, err := session.Asc("batch").Get(&m)
	if has == false || err != nil {
		return nil, err
	}
	return &m, nil
}
func CouponUserOrdById(eg *xorm.Engine, id string) (*model.CommCouponUserOrd, error) {
	var m model.CommCouponUserOrd

	has, err := eg.Where("id=?", id).Get(&m)
	if has == false || err != nil {
		return nil, err
	}
	return &m, nil
}
func CouponUserOrdByGidAscBatchALL(session *xorm.Session, uid string, gid string, refundState int, batch int, goodsType string) (*[]model.CommCouponUserOrd, error) {
	var m []model.CommCouponUserOrd
	session = session.Where("uid=? AND  type= ? and gid=? and refund_state=? and batch=?", uid, 1, gid, refundState, batch)
	if goodsType != "" {
		session = session.And("goods_type=?", goodsType)
	}
	err := session.Find(&m)
	if err != nil {
		return nil, err
	}
	return &m, nil
}

func CouponUserOrdByGidAscBatchWithEg(eg *xorm.Engine, uid string, gid string, refundState int, goodsType string) (*model.CommCouponUserOrd, error) {
	var m model.CommCouponUserOrd
	session := eg.Where("uid=? AND  type= ? and gid=? and refund_state=?", uid, 1, gid, refundState)
	if goodsType != "" {
		session = session.And("goods_type=?", goodsType)
	}
	has, err := session.Asc("batch").Get(&m)
	if has == false || err != nil {
		return nil, err
	}
	return &m, nil
}
func CouponUserOrdByGidAscBatchALLWithEg(eg *xorm.Engine, uid string, gid string, refundState int, batch int, goodsType string) (*[]model.CommCouponUserOrd, error) {
	var m []model.CommCouponUserOrd
	session := eg.Where("uid=? AND  type= ? and gid=? and refund_state=? and batch=?", uid, 1, gid, refundState, batch)
	if goodsType != "" {
		session = session.And("goods_type=?", goodsType)
	}
	err := session.Find(&m)
	if err != nil {
		return nil, err
	}
	return &m, nil
}
func CouponUserOrdByInsertOne(eg *xorm.Engine, m *model.CommCouponUserOrd) bool {
	_, err := eg.InsertOne(m)
	if err != nil {
		return false
	}
	return true
}
func CouponUserOrdByInsertOneWithSession(session *xorm.Session, m *model.CommCouponUserOrd) bool {
	_, err := session.InsertOne(m)
	if err != nil {
		return false
	}
	return true
}
func commWhere(Db *xorm.Engine, uid int, types, pvdType, times string, ordType []string, keyword string) *xorm.Session {
	dbWhere := Db.Where("1=1")
	if uid > 0 {
		dbWhere = dbWhere.And("uid=?", uid)
	}
	if pvdType != "" {
		dbWhere = dbWhere.And("pvd_type=?", pvdType)
	}
	if times != "" {
		dbWhere = dbWhere.And("create_at like ?", times+"%")
	}
	if len(ordType) > 0 {
		dbWhere = dbWhere.In("ord_type", ordType)
	}
	if types == "output" {
		dbWhere = dbWhere.And("type=?", 1)
	} else if types == "input" {
		dbWhere = dbWhere.And("type=?", 0)
	}
	if keyword != "" {
		userOne, _ := UserFindByPhoneOrNickname(Db, keyword)
		uids := "0"
		if userOne != nil {
			uids = utils.IntToStr(userOne.Uid)
		}
		dbWhere = dbWhere.And("to_uid = ? and to_uid>0", uids)
	}
	return dbWhere
}
func CouponUserOrdList(Db *xorm.Engine, uid int, types, pvdType, times string, limit, start int, keyword string) ([]*model.CommCouponUserOrd, error) {
	var m []*model.CommCouponUserOrd
	dbWhere := commWhere(Db, uid, types, pvdType, times, []string{}, keyword)
	err := dbWhere.Desc("create_at").Limit(limit, start).Find(&m)
	if err != nil {
		return nil, err
	}
	return m, nil
}
func CouponUserOrdListWithOrdType(Db *xorm.Engine, uid int, types, pvdType string, limit, start int, ordType []string, keyword string) ([]*model.CommCouponUserOrd, error) {
	var m []*model.CommCouponUserOrd
	dbWhere := commWhere(Db, uid, types, pvdType, "", ordType, keyword)
	err := dbWhere.Desc("create_at").Limit(limit, start).Desc("create_at").Find(&m)
	if err != nil {
		return nil, err
	}
	return m, nil
}
func CouponUserOrdByGid(session *xorm.Session, uid int, types, gid, goodsType string) (*model.CommCouponUserOrd, error) {
	var m model.CommCouponUserOrd
	has, err := session.Where("uid=? AND  type= ? and gid=? and goods_type=?", uid, types, gid, goodsType).Desc("batch").Get(&m)
	if has == false || err != nil {
		return nil, err
	}
	return &m, nil
}
func CouponUserOrdByGidAndTime(session *xorm.Session, expectedRefundTime int64) (*[]model.CommCouponUserOrd, error) {
	var m []model.CommCouponUserOrd
	err := session.Where("ord_type= ? and  type= ?  and refund_state=? and expected_refund_time<?", 3, 1, 0, expectedRefundTime).Find(&m)
	if err != nil {
		return nil, err
	}
	return &m, nil
}
func CouponUserOrdSum(Db *xorm.Engine, uid int, types, pvdType, times, cols string, keyword string) (float64, error) {
	dbWhere := commWhere(Db, uid, types, pvdType, times, []string{}, keyword)
	m := new(model.CommCouponUserOrd)
	total, err := dbWhere.Sum(m, cols)
	if err != nil {
		return 0, err
	}
	return total, err
}
func CouponUserOrdSumWithToUid(Db *xorm.Engine, uid, types, toUid int, pvdType, ordType string) (float64, error) {
	m := new(model.CommCouponUserOrd)
	total, err := Db.Where("uid=? and type=? and to_uid=? and pvd_type=? and ord_type=?", uid, types, toUid, pvdType, ordType).Sum(m, "coupon_amount_value")
	if err != nil {
		return 0, err
	}
	return total, err
}
func CouponUserOrdByUpdate(session *xorm.Session, m *model.CommCouponUserOrd) bool {
	_, err := session.Where("id=?", m.Id).Cols("refund_state").Update(m)
	if err != nil {
		return false
	}
	return true
}
func CouponUserOrdByUpdateWithEg(eg *xorm.Engine, m *model.CommCouponUserOrd) bool {
	_, err := eg.Where("id=?", m.Id).Cols("refund_state").Update(m)
	if err != nil {
		return false
	}
	return true
}
